This function generates the column names of a rand walk data frame.
rand_walk_column_names(.rand_data, .dim_names, .num_sims, .t)A data frame from which column names are to be extracted.
The dimnames passed from the rand walk function.
The number of simulations.
Ther periods in the walk
Steven P. Sanderson II, MPH
The rand_walk_column_names function takes a data frame as input and
returns the rand walk data with column names.
Other Utility Functions:
confidence_interval(),
convert_snake_to_title_case(),
generate_caption(),
get_attributes(),
rand_walk_helper(),
running_quantile(),
std_cum_max_augment(),
std_cum_mean_augment(),
std_cum_min_augment(),
std_cum_prod_augment(),
std_cum_sum_augment(),
subset_walks()