Learn R Programming

RandomWalker (version 1.1.0)

std_cum_sum_augment: Augment Cumulative Sum

Description

This function augments a data frame by adding cumulative sum columns for specified variables.

Usage

std_cum_sum_augment(.data, .value, .names = "auto", .initial_value = 0)

Value

A tibble with the original data and additional columns containing the cumulative sums.

Arguments

.data

A data frame to augment.

.value

A column name or names for which to compute the cumulative sum.

.names

Optional. A character vector of names for the new cumulative sum columns. Defaults to "auto", which generates names based on the original column names.

.initial_value

A numeric value to start the cumulative sum from. Defaults to 0.

Author

Steven P. Sanderson II, MPH

Details

The function takes a data frame and a column name (or names) and computes the cumulative sum for each specified column, starting from an initial value. If the column names are not provided, it will throw an error.

See Also

Other Utility Functions: confidence_interval(), convert_snake_to_title_case(), generate_caption(), get_attributes(), rand_walk_column_names(), rand_walk_helper(), running_quantile(), std_cum_max_augment(), std_cum_mean_augment(), std_cum_min_augment(), std_cum_prod_augment(), subset_walks()

Examples

Run this code
df <- data.frame(x = 1:5, y = 6:10)
std_cum_sum_augment(df, .value = x)
std_cum_sum_augment(df, .value = y, .names = c("cumsum_y"))

Run the code above in your browser using DataLab